/*
  libuta - a C++ widget library based on SDL (Simple Direct Layer)
  Copyright (C) 1999-2002  Karsten Laux

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307, SA.
*/

// created by Karsten Laux, 2/2000

#ifndef _DIALOGBOX_H
#define _DIALOGBOX_H

#include "dialog.h"

namespace uta {

/**DialogBox.
   Modal Dialogbox with border and optional title.
   
   changed name to uDialogBox to escape Win32 nasties. [MW]
*/
class uDialogBox : public Dialog
{
 public:
  ///
  uDialogBox(const std::string& title ="");
  ///
  virtual ~uDialogBox();
 

 protected:
  ///
  Surface* titleSurface_;

};


}

#endif // !_DIALOGBOX_H
